Documentation
¶
Index ¶
Constants ¶
const ( // DefaultAddress is the default used by mDNS // and in most cases should be the address that the // net.Conn passed to Server is bound to DefaultAddress = "224.0.0.0:5353" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// QueryInterval controls how ofter we sends Queries until we
// get a response for the requested name
QueryInterval time.Duration
// LocalNames are the names that we will generate answers for
// when we get questions
LocalNames []string
LoggerFactory logging.LoggerFactory
}
Config is used to configure a mDNS client or server.
Click to show internal directories.
Click to hide internal directories.